@@ -1,6 +1,6 @@
 package Package::Pkg;
 BEGIN {
-  $Package::Pkg::VERSION = '0.0016';
+  $Package::Pkg::VERSION = '0.0017';
 }
 # ABSTRACT: Handy package munging utilities
 
@@ -89,46 +89,47 @@ sub install {
     my $self = shift;
     my %install;
     if      ( @_ == 1 ) { %install = %{ $_[0] } }
-    elsif   ( @_ == 2 ) { @install{qw/ code into /} = @_ }
+    elsif   ( @_ == 2 ) {
+        if ( $_[1] && $_[1] =~ m/::$/ ) { @install{qw/ code into /} = @_ }
+        else                            { @install{qw/ code as /} = @_ }
+    }
     elsif   ( @_ == 3 ) { @install{qw/ code into as /} = @_ }
     else                { %install = @_ }
 
     my ( $from, $code, $into, $_into, $as, ) = @install{qw/ from code into _into as /};
     undef %install;
 
-    die "Missing code" unless defined $code;
+    die "Missing code (@_)" unless defined $code;
 
     if ( ref $code eq 'CODE' ) {
-        die "Invalid (superfluous) from ($from) with code reference" if defined $from;
+        die "Invalid (superfluous) from ($from) with code reference (@_)" if defined $from;
     }
     else {
         if ( defined $from )
             { die "Invalid code ($code) with from ($from)" if $code =~ m/::/ }
-        elsif ( $code =~ m/::/)
-            { ( $from, $code ) = $self->split2( $code ) }
-        else                    
-            { $from = caller }
+        elsif ( $code =~ m/::/) {
+            $code =~ s/^<//; # Silently allow <Package::subroutine
+            ( $from, $code ) = $self->split2( $code );
+        }
+        else { $from = caller }
     }
 
     if ( defined $as && $as =~ m/::/) {
         die "Invalid as ($as) with into ($into)" if defined $into;
         ( $into, $as ) = $self->split2( $as );
     }
-    elsif ( defined $into && ! defined $as ) {
+    elsif ( defined $into ) {
         if ( $into =~ s/::$// ) { }
-        else {
-            ( $into, $as ) = $self->split2( $into );
-        }
     }
-    elsif ( defined $_into && ! defined $into ) {
+    elsif ( defined $_into ) {
         $into = $_into;
     }
 
     if      ( defined $as ) {}
     elsif   ( ! ref $code ) { $as = $code }
-    else                    { die "Missing as" }
+    else                    { die "Missing as (@_)" }
 
-    die "Missing into" unless defined $into;
+    die "Missing into (@_)" unless defined $into;
 
     @install{qw/ code into as /} = ( $code, $into, $as );
     $install{from} = $from if defined $from;
@@ -145,7 +146,7 @@ sub split {
 sub split2 {
     my $self = shift;
     return unless my @split = $self->split( @_ );
-    return join '::', @split if 1 == @split;
+    return $split[0] if 1 == @split;
     my $name = pop @split;
     return( join( '::', @split ), $name );
 }
@@ -155,7 +156,7 @@ sub export {
     my $exporter = $self->exporter( @_ );
 
     my $package = caller;
-    $self->install( code => $exporter, into => "${package}::import" );
+    $self->install( code => $exporter, as => "${package}::import" );
 }
 
 sub exporter {
@@ -163,6 +164,7 @@ sub exporter {
     my ( %index, %group, $default_export );
     %group = ( default => [], optional => [], all => [] );
     $default_export = 1;
+
     while ( @_ ) {
         local $_ = shift;
         my ( $group, @install );
@@ -224,7 +226,7 @@ Package::Pkg - Handy package munging utilities
 
 =head1 VERSION
 
-version 0.0016
+version 0.0017
 
 =head1 SYNOPSIS
 
@@ -272,11 +274,148 @@ Package::Pkg is a collection of useful, miscellaneous package-munging utilities.
 
 =head2 pkg->install( ... )
 
-Install a subroutine, similar to L<Sub::Install> (and actually using that module to do the dirty work)
+Install a subroutine, similar to L<Sub::Install>
 
-=head2 $package = pkg->name( <part>, [ <part>, ..., <part> ] )
+This method takes a number of parameters and also has a two- and three-argument form (see below)
 
-Return a namespace composed by joining each <part> with C<::>
+    # Install an anonymous subroutine as Banana::magic
+    pkg->install( code => sub { ... } , as => 'Banana::magic' )
+    pkg->install( code => sub { ... } , into => 'Banana::magic' ) # Bzzzt! Throws an error!
+
+    # Install the subroutine Apple::xyzzy as Banana::magic
+    pkg->install( code => 'Apple::xyzzy', as => 'Banana::magic' )
+    pkg->install( code => 'Apple::xyzzy', into => 'Banana', as => 'magic' )
+    pkg->install( from => 'Apple', code => 'xyzzy', as => 'Banana::magic' )
+    pkg->install( from => 'Apple', code => 'xyzzy', into => 'Banana', as => 'magic' )
+
+    # Install the subroutine Apple::xyzzy as Banana::xyzzy
+    pkg->install( code => 'Apple::xyzzy', as => 'Banana::xyzzy' )
+    pkg->install( code => 'Apple::xyzzy', into => 'Banana' )
+    pkg->install( from => 'Apple', code => 'xyzzy', as => 'Banana::xyzzy' )
+    pkg->install( from => 'Apple', code => 'xyzzy', into => 'Banana' )
+
+With implicit C<from> (via C<caller()>)
+
+    package Apple;
+
+    sub xyzzy { ... }
+
+    # Install the subroutine Apple::xyzzy as Banana::xyzzy
+    pkg->install( code => 'xyzzy', as => 'Banana::xyzzy' ) # 'from' is implicitly 'Apple'
+    pkg->install( code => \&xyzzy, as => 'Banana::xyzzy' )
+
+Acceptable parameters are:
+
+    code            A subroutine reference,
+                    A package-with-name identifier, or
+                    The name of a subroutine in the calling package
+
+    from (optional) A package identifier
+                    If :code is an identifier, then :from is the package where
+                    the subroutine can be found
+                    If :code is an identifier and :from is not given, then :from
+                    is assumed to be the calling package (via caller())
+
+    as              The name of the subroutine to install as. Can be a simple name
+                    (when paired with :into) or a full package-with-name 
+
+    into (optional) A package identifier
+                    If :as is given, then the full name of the installed
+                    subroutine is (:into)::(:as)
+
+                    If :as is not given and we can derive a simple name from
+                    :code (It is a package-with-name identifier), then :as will be 
+                    the name identifier part of :code
+
+=head2 pkg->install( $code => $as )
+
+This is the two-argument form of subroutine installation
+
+Install $code subroutine as $as
+
+    pkg->install( sub { ... } => 'Banana::xyzzy' )
+
+    pkg->install( 'Scalar::Util::blessed' => 'Banana::xyzzy' )
+
+    pkg->install( 'Scalar::Util::blessed' => 'Banana::' )
+
+    pkg->install( sub { ... } => 'Banana::' ) # Bzzzt! Throws an error!
+
+$code should be:
+
+=over
+
+=item * A CODE reference
+
+    sub { ... }
+
+=item * A package-with-name identifier
+
+    Scalar::Util::blessed
+
+=item * The name of a subroutine in the calling package
+
+    sub xyzzy { ... }
+
+    pkg->install( 'xyzzy' => ... )
+
+=back
+
+$as should be:
+
+=over
+
+=item * A package-with-name identifier
+
+    Acme::Xyzzy::magic
+
+=item * A package identifier (with a trailing ::)
+
+    Acme::Xyzzy::
+
+=back
+
+=head2 pkg->install( $code => $into, $as )
+
+This is the three-argument form of subroutine installation
+
+    pkg->install( sub { ... } => 'Banana', 'xyzzy' )
+
+    pkg->install( sub { ... } => 'Banana::', 'xyzzy' )
+
+    pkg->install( 'Scalar::Util::blessed' => 'Banana', 'xyzzy' )
+
+    pkg->install( 'Scalar::Util::blessed' => 'Banana::', 'xyzzy' )
+
+$code can be the same as the two argument form
+
+$into should be:
+
+=over
+
+=item * A package identifier (trailing :: is optional)
+
+    Acme::Xyzzy::
+
+    Acme::Xyzzy
+
+=back
+
+$as should be:
+
+=over
+
+=item * A name (the name of the subroutine)
+
+    xyzzy
+
+    magic
+
+=back
+
+=head2 $package = pkg->name( $part, [ $part, ..., $part ] )
+
+Return a namespace composed by joining each $part with C<::>
 
 Superfluous/redundant C<::> are automatically cleaned up and stripped from the resulting $package
 
